/* BdfServer_Commands - Copyright (c) 2010-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.configuration;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.BdfServerEditor;
import fr.exemole.bdfserver.tools.configuration.LangConfigurationBuilder;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfErrors;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.LangsUtils;
import net.mapeadores.util.logging.ErrorMessageException;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class LangConfigCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "LangConfig";
    public final static String COMMANDKEY = "_ CNF-03";
    public final static String WORKINGLANG_PARAMNAME = "workinglang";
    public final static String SUPPLEMENTARYLANG_PARAMNAME = "supplementarylang";
    public final static String ALLLANG_PARAMNAME = "alllang";
    public final static String WITHNONLATIN_PARAMNAME = "withnonlatin";
    public final static String WITHOUTSURNAMEFIRST = "withoutsurnamefirst";
    private Lang[] workingArray;
    private Lang[] supplementaryArray;
    private boolean allLanguage;
    private boolean withNonlatin;
    private boolean withoutSurnameFirst;

    public LangConfigCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws ErrorMessageException {
        LangConfigurationBuilder langConfigurationBuilder = new LangConfigurationBuilder();
        int workingCount = workingArray.length;
        for (int i = 0; i < workingCount; i++) {
            langConfigurationBuilder.addWorkingLang(workingArray[i]);
        }
        langConfigurationBuilder.setAllLanguages(allLanguage);
        if (!allLanguage) {
            int supplementaryCount = supplementaryArray.length;
            for (int i = 0; i < supplementaryCount; i++) {
                langConfigurationBuilder.addSupplementaryLang(supplementaryArray[i]);
            }
        }
        langConfigurationBuilder.setWithNonlatin(withNonlatin);
        langConfigurationBuilder.setWithoutSurnameFirst(withoutSurnameFirst);
        BdfServerEditor bdfServerEditor = bdfServer.getBdfServerEditor();
        bdfServerEditor.setLangConfiguration(langConfigurationBuilder.toLangConfiguration());
        bdfServerEditor.saveChanges();
        setDone("_ done.configuration.langconfig");
    }

    @Override
    protected void checkParameters() throws ErrorMessageException {
        checkFichothequeAdmin();
        String workingLangParam = getMandatory(WORKINGLANG_PARAMNAME);
        workingArray = LangsUtils.toCleanLangArray(workingLangParam);
        if (workingArray.length == 0) {
            throw BdfErrors.error("_ error.empty.workinglang");
        }
        allLanguage = requestMap.isTrue(ALLLANG_PARAMNAME);
        if (!allLanguage) {
            String supplementaryLangParam = getMandatory(SUPPLEMENTARYLANG_PARAMNAME);
            supplementaryArray = LangsUtils.toCleanLangArray(supplementaryLangParam);
        }
        withNonlatin = requestMap.isTrue(WITHNONLATIN_PARAMNAME);
        withoutSurnameFirst = requestMap.isTrue(WITHOUTSURNAMEFIRST);
    }

}
